'use client';

import React, { useTransition } from 'react';
import { Button, Dropdown } from 'antd';
import type { MenuProps } from 'antd';
import { useRouter, usePathname } from '../../../navigation';
import { LOCALES } from '../../../constants/locale';
import { Locale } from '../../../types/locale';

export const LanguageSwitcher = ({ locale }: { locale: string }) => {
    const router = useRouter();
    const [isPending, startTransition] = useTransition();
    const pathname = usePathname();

    const onClick: MenuProps['onClick'] = (e) => {
        startTransition(() => {
            router.replace(pathname, { locale: e.key });
        });
    };

    const menuProps = {
        items: Object.entries(LOCALES).map(([ key, label ]) => ({ key, label })),
        selectable: true,
        defaultSelectedKeys: [locale],
        onClick
    };

    return (
        <Dropdown menu={menuProps} disabled={isPending}>
            <Button>
                {LOCALES[locale as Locale]}
            </Button>
        </Dropdown>
    );
};
